@@ -1,3 +1,4 @@
+from __future__ import annotations
 EXTENSIONS = {
     'adoc': {'text', 'asciidoc'},
     'ai': {'binary', 'adobe-illustrator'},
@@ -177,6 +178,7 @@ EXTENSIONS = {
     'spec': {'text', 'spec'},
     'sql': {'text', 'sql'},
     'ss': {'text', 'scheme'},
+    'sty': {'text', 'tex'},
     'styl': {'text', 'stylus'},
     'sv': {'text', 'system-verilog'},
     'svelte': {'text', 'svelte'},
